#include <avr/io.h> 
#include <avr/interrupt.h>   
#include <util/delay.h>
#include <avr/pgmspace.h>

// all on PORTC
#define	LCD_CD	PC7   
#define	LCD_RW  PC6	// WR in 8080 modez
#define	LCD_E	  PC5	// RD in 8080 mode
#define	LCD_WR  PC6	// WR in 8080 mode
#define	LCD_RD  PC5	// RD in 8080 mode
#define	LCD_CS	PC4
#define	LCD_RES	PC2

#define CLR_CD PORTC &= ~(1<<LCD_CD);
#define SET_CD PORTC |=  (1<<LCD_CD);

#define CLR_CS PORTC &= ~(1<<LCD_CS);
#define SET_CS PORTC |=  (1<<LCD_CS);

#define CLR_RESET PORTC &= ~(1<<LCD_RES);
#define SET_RESET PORTC |=  (1<<LCD_RES);

// 6800 mode pin functions
#define CLR_RW PORTC &= ~(1 << LCD_RW);   // 6800 mode
#define SET_RW PORTC |=  (1 << LCD_RW);   // 6800 mode
#define CLR_E  PORTC &= ~(1 << LCD_E);    // 6800 mode
#define SET_E  PORTC |=  (1 << LCD_E);    // 6800 mode

// 8080 mode pin functions
#define CLR_WR PORTC &= ~(1 << LCD_WR);   // 8080 mode
#define SET_WR PORTC |=  (1 << LCD_WR);   // 8080 mode
#define CLR_RD PORTC &= ~(1 << LCD_RD);   // 8080 mode
#define SET_RD PORTC |=  (1 << LCD_RD);   // 8080 mode

#define MODE6800	0

//Bitmap to be displayed on OLED module
unsigned char Data_12864greynocolorsbmp[4096] = {
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC1, 0x03, 0x30, 0x9F, 0x80, 0x00, 0x00, 0x8F, 0xF8, 0x05, 0xFF, 0xFF, 0xF0, 0x8F, 0xFF, 0xFF, 0xFF, 0xC5, 0x7F, 0xFF, 0xFA, 0x30, 0x18, 0xFF, 0xFF, 0xA3, 0x05, 0xCF, 0xFF, 0xFE, 0x83, 0x0F, 0xFF, 0xFF, 0xF8, 0x3C, 0xFF, 0x00, 0x00, 0x00, 0x08, 	/* Line: 1 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0x15, 0xEF, 0xFE, 0xEF, 0x80, 0xFF, 0xFF, 0xFF, 0xF5, 0x11, 0xFF, 0xFF, 0xF0, 0x8F, 0xFF, 0xFF, 0xF8, 0x00, 0x3F, 0xFF, 0xD1, 0x8B, 0x70, 0x9F, 0xFA, 0x08, 0xA3, 0x0E, 0xFF, 0xE3, 0x15, 0x8F, 0xFF, 0xFF, 0xD0, 0x0B, 0xFF, 0xFF, 0xFF, 0xF5, 0x1E, 	/* Line: 2 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF1, 0x3F, 0xFF, 0xFF, 0xFF, 0x80, 0xFF, 0xFF, 0xFF, 0xF0, 0x90, 0xBF, 0xFF, 0xF0, 0x8F, 0xFF, 0xFF, 0xF5, 0xB3, 0x5F, 0xFF, 0xFC, 0xFF, 0xF3, 0x3F, 0xF3, 0x5F, 0xFD, 0x09, 0xFF, 0x33, 0xEF, 0xFF, 0xFF, 0xFF, 0x53, 0x0B, 0xFF, 0xFF, 0xFF, 0xB0, 0x9F, 	/* Line: 3 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC0, 0xCF, 0xFF, 0xFF, 0xFF, 0x80, 0xFF, 0xFF, 0xFF, 0xA0, 0xE1, 0x7F, 0xFF, 0xF0, 0x8F, 0xFF, 0xFF, 0xFF, 0xF5, 0x3F, 0xFF, 0xFF, 0xFF, 0xF8, 0x0F, 0xF0, 0x8F, 0xFF, 0x08, 0xF9, 0x1D, 0xFF, 0xFF, 0xFF, 0xFB, 0x09, 0x0B, 0xFF, 0xFF, 0xFF, 0x31, 0xFF, 	/* Line: 4 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x0F, 0xF0, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0x81, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0xFF, 0xFF, 0xFF, 0x73, 0xF7, 0x3F, 0xFF, 0xF0, 0x8F, 0xFF, 0xFF, 0xFF, 0xF3, 0x3F, 0xFF, 0xFF, 0xFF, 0xF8, 0x1F, 0xF3, 0x3F, 0xFB, 0x0D, 0xF5, 0x5D, 0x89, 0xEF, 0xFF, 0xF3, 0x7B, 0x0B, 0xFF, 0xFF, 0xFA, 0x0A, 0xFF, 	/* Line: 5 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x0F, 0xFF, 0xF0, 0x00, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x53, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0xBB, 0xBB, 0xFF, 0x18, 0xFA, 0x0D, 0xFF, 0xF0, 0x8F, 0xFF, 0xFF, 0xFF, 0xF5, 0x3F, 0xFF, 0xFF, 0xFF, 0xF3, 0x7F, 0xFC, 0x13, 0x81, 0x9F, 0xF0, 0x51, 0x30, 0x3E, 0xFF, 0xA1, 0xEB, 0x0B, 0xFF, 0xFF, 0xF1, 0x3F, 0xFF, 	/* Line: 6 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0x0F, 0xF0, 0x00, 0x0F, 0xFF, 0xFF, 0xF0, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0x53, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0x00, 0x00, 0xFD, 0x0C, 0xFE, 0x09, 0xFF, 0xF0, 0x8F, 0xFF, 0xFF, 0xFF, 0xF3, 0x5F, 0xFF, 0xFF, 0xFF, 0xB0, 0xBF, 0xFF, 0x50, 0x01, 0xCF, 0xD0, 0x1E, 0xFC, 0x17, 0xFF, 0x18, 0xFB, 0x0B, 0xFF, 0xFF, 0x90, 0xBF, 0xFF, 	/* Line: 7 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0x33, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0xFF, 0xFF, 0xF8, 0x08, 0x88, 0x15, 0xFF, 0xF0, 0x8F, 0xFF, 0xFF, 0xFF, 0xF5, 0x3F, 0xFF, 0xFF, 0xFF, 0x33, 0xFF, 0xF5, 0x3D, 0xD3, 0x1D, 0xB0, 0xAF, 0xFF, 0x51, 0xF8, 0x3F, 0xFB, 0x0B, 0xFF, 0xFE, 0x15, 0xFF, 0xFF, 	/* Line: 8 */
  0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0x80, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0xFF, 0xFF, 0xF5, 0x15, 0x35, 0x11, 0xFF, 0xF0, 0x8F, 0xFF, 0xFF, 0xFF, 0xF3, 0x3F, 0xFF, 0xFF, 0xF7, 0x1D, 0xFF, 0xC0, 0xBF, 0xFE, 0x17, 0xB0, 0xBF, 0xFF, 0x80, 0xF1, 0x13, 0x53, 0x03, 0x7F, 0xF8, 0x0D, 0xFF, 0xFF, 	/* Line: 9 */
  0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xA0, 0xAF, 0xFF, 0xFF, 0xFF, 0x80, 0xFF, 0xFF, 0xF1, 0x8F, 0xFF, 0xB0, 0xCF, 0xF0, 0x8F, 0xFF, 0xFF, 0xFF, 0xF5, 0x3F, 0xFF, 0xFF, 0x90, 0xAF, 0xFF, 0x80, 0xFF, 0xFF, 0x33, 0xF0, 0xAF, 0xFF, 0x81, 0xF8, 0x88, 0x85, 0x05, 0x9F, 0xD1, 0x7F, 0xFF, 0xFF, 	/* Line: 10 */
  0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xF1, 0x3E, 0xFF, 0xFF, 0xFF, 0x80, 0xFF, 0xFF, 0xB0, 0xCF, 0xFF, 0xF0, 0x8F, 0xF0, 0x8F, 0xFF, 0xFF, 0xFF, 0xF3, 0x3F, 0xFF, 0xFC, 0x18, 0xFF, 0xFF, 0x90, 0xDF, 0xFF, 0x17, 0xF3, 0x5F, 0xFF, 0x35, 0xFF, 0xFF, 0xFB, 0x0B, 0xFF, 0x51, 0xEF, 0xFF, 0xFF, 	/* Line: 11 */
  0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFC, 0x13, 0xAF, 0xFA, 0xDF, 0x80, 0xFF, 0xFF, 0x71, 0xFF, 0xFF, 0xF5, 0x3F, 0xF0, 0x5B, 0xBB, 0xBE, 0xFF, 0xF3, 0x5F, 0xFF, 0xD0, 0x3B, 0xBB, 0xBE, 0xE1, 0x3D, 0xE7, 0x0B, 0xFA, 0x08, 0xF8, 0x0B, 0xFF, 0xFF, 0xFB, 0x0B, 0xFD, 0x05, 0xBB, 0xBB, 0xBD, 	/* Line: 12 */
  0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xC3, 0x00, 0x00, 0x9F, 0x80, 0xFF, 0xFF, 0x37, 0xFF, 0xFF, 0xF8, 0x0E, 0xF0, 0x00, 0x00, 0x0B, 0xFF, 0xF3, 0x5F, 0xFF, 0x80, 0x00, 0x00, 0x0B, 0xFC, 0x10, 0x01, 0x9F, 0xFF, 0x80, 0x01, 0x9F, 0xFF, 0xFF, 0xFB, 0x0B, 0xF8, 0x00, 0x00, 0x00, 0x08, 	/* Line: 13 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEB, 0xCF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0xCF, 0xFF, 0xFF, 0xFE, 0xBF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 	/* Line: 14 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 	/* Line: 15 */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 	/* Line: 16 */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 	/* Line: 17 */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xBB, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFD, 0xBD, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 	/* Line: 18 */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0x50, 0x00, 0x19, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0xCF, 0xFF, 0xFF, 0xFF, 0xFF, 0x50, 0x8F, 0xB0, 0x00, 0xDF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0xCF, 0xFF, 0xFF, 0xFF, 	/* Line: 19 */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xE3, 0x03, 0x85, 0x00, 0xBF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0xCF, 0xFF, 0xFF, 0xFF, 0xFF, 0x30, 0xCF, 0x50, 0x7B, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x80, 0xCF, 0xFF, 0xFF, 0xFF, 	/* Line: 20 */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0x50, 0x5F, 0xFF, 0x80, 0x5F, 0xCB, 0xD9, 0x8B, 0xBF, 0xFF, 0xDB, 0xDF, 0xD8, 0x89, 0xEF, 0xDB, 0x00, 0xBF, 0xE9, 0x88, 0xCF, 0xFE, 0x00, 0xEB, 0x30, 0x8E, 0xFE, 0x98, 0x8E, 0xFF, 0xFB, 0xBE, 0xB8, 0xBF, 0xDB, 0x00, 0xBE, 0xBB, 0xBB, 0xBC, 	/* Line: 21 */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFD, 0x00, 0xDF, 0xFF, 0xEB, 0xFF, 0x30, 0x30, 0x53, 0x0D, 0xFF, 0x30, 0xB9, 0x00, 0x00, 0x1D, 0x50, 0x00, 0x3C, 0x10, 0x00, 0x09, 0xFB, 0x03, 0x90, 0x00, 0x0D, 0xC1, 0x00, 0x01, 0xCF, 0xF0, 0x05, 0x00, 0x0B, 0x50, 0x00, 0x39, 0x00, 0x00, 0x05, 	/* Line: 22 */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF9, 0x03, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x3B, 0xE3, 0x0B, 0xF9, 0x05, 0xF1, 0x0E, 0xE7, 0x5B, 0xC5, 0x05, 0xC8, 0x39, 0xF8, 0x03, 0xF8, 0x07, 0xD8, 0x03, 0xBF, 0x30, 0x8F, 0x80, 0x3F, 0xB0, 0x07, 0xF5, 0x08, 0xC5, 0x05, 0xCD, 0xBB, 0x80, 0x0B, 	/* Line: 23 */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF8, 0x08, 0xFF, 0xFF, 0xFF, 0xFB, 0x01, 0xEF, 0xF8, 0x09, 0xF3, 0x0D, 0xF1, 0x03, 0x8D, 0xFF, 0xF3, 0x0B, 0xFF, 0xFB, 0xB5, 0x05, 0xF3, 0x09, 0xF8, 0x07, 0xF9, 0x03, 0xFF, 0xF0, 0x0F, 0x80, 0x3F, 0xF3, 0x09, 0xF3, 0x0B, 0xFF, 0xFC, 0x10, 0x9F, 	/* Line: 24 */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF8, 0x08, 0xFF, 0xFF, 0xFF, 0xF8, 0x05, 0xFF, 0xF9, 0x08, 0xB0, 0x7F, 0xFB, 0x30, 0x00, 0x9F, 0xF0, 0x0E, 0xF7, 0x00, 0x11, 0x08, 0xF1, 0x0D, 0xF5, 0x09, 0xF8, 0x07, 0xFF, 0xE0, 0x0F, 0x50, 0x9F, 0xF1, 0x0D, 0xF0, 0x0E, 0xFF, 0xC1, 0x09, 0xFF, 	/* Line: 25 */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF9, 0x03, 0xFF, 0xFE, 0x13, 0xE5, 0x09, 0xFF, 0xFB, 0x05, 0x31, 0xEF, 0xFF, 0xFB, 0x50, 0x1F, 0xC0, 0x3F, 0x90, 0x3D, 0xF3, 0x0B, 0xD0, 0x3F, 0xF1, 0x0D, 0xF8, 0x08, 0xFF, 0x90, 0x3F, 0x10, 0xDF, 0xD0, 0x3F, 0xC0, 0x3F, 0xFC, 0x10, 0x9F, 0xFF, 	/* Line: 26 */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0x10, 0x5B, 0x93, 0x07, 0xF3, 0x0C, 0xFF, 0xFF, 0x01, 0x08, 0xFE, 0x31, 0xBF, 0xB0, 0x3F, 0x80, 0x5F, 0x70, 0x5F, 0x80, 0x0F, 0x90, 0x5F, 0xD0, 0x1F, 0xFB, 0x03, 0xED, 0x30, 0x9D, 0x01, 0xFF, 0x90, 0x5F, 0x80, 0x5F, 0xD1, 0x05, 0xBB, 0xBF, 	/* Line: 27 */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0x91, 0x00, 0x00, 0x7F, 0xE0, 0x1F, 0xFF, 0xFF, 0x30, 0x3F, 0xFF, 0x70, 0x00, 0x01, 0x9F, 0x90, 0x01, 0xC0, 0x00, 0x30, 0x0F, 0x70, 0x8F, 0x90, 0x3F, 0xFF, 0x50, 0x00, 0x07, 0xFB, 0x05, 0xFF, 0x70, 0x8F, 0x90, 0x01, 0x90, 0x00, 0x00, 0x3F, 	/* Line: 28 */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFD, 0x88, 0x8D, 0xFF, 0xEB, 0xCF, 0xFF, 0xFF, 0x30, 0xBF, 0xFF, 0xFC, 0x87, 0x8D, 0xEE, 0xE9, 0x79, 0xEC, 0x79, 0xEB, 0xBE, 0xBB, 0xDE, 0xDB, 0xCF, 0xEE, 0xFB, 0x77, 0xBF, 0xFC, 0xBC, 0xFF, 0xBB, 0xEF, 0xF9, 0x79, 0xDB, 0xBB, 0xBB, 0xCF, 	/* Line: 29 */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xB5, 0x03, 0xFF, 0xFF, 0xFF, 0xEE, 0xEE, 0xEE, 0xEE, 0xDD, 0xED, 0xED, 0xED, 0xED, 0xED, 0xEE, 0xED, 0xED, 0xEE, 0xDE, 0xDE, 0xEE, 0xEE, 0xEE, 0xEE, 0xFF, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 	/* Line: 30 */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0x00, 0x3F, 0xFF, 0xFF, 0xFE, 0xEE, 0xED, 0xDD, 0xDD, 0xDD, 0xDD, 0xDC, 0xDD, 0xCC, 0xCC, 0xCC, 0xCC, 0xCC, 0xCD, 0xDD, 0xDD, 0xDD, 0xDE, 0xDE, 0xEE, 0xED, 0xEE, 0xEE, 0xEE, 0xEF, 0xEF, 0xFE, 0xEE, 	/* Line: 31 */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xBB, 0xFF, 0xFF, 0xFE, 0xEE, 0xED, 0xDC, 0xCC, 0xCC, 0xCC, 0xCC, 0xCC, 0xBC, 0xBB, 0xBB, 0xBB, 0xBB, 0xBB, 0xBC, 0xCC, 0xCC, 0xCC, 0xCC, 0xCC, 0xDC, 0xCC, 0xED, 0xEE, 0xFE, 0xEE, 0xFE, 0xEE, 0xEE, 	/* Line: 32 */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEE, 0xED, 0xDC, 0xCC, 0xBC, 0xBB, 0xBB, 0xBB, 0xBB, 0x9B, 0x99, 0x99, 0x99, 0x99, 0x9B, 0x9B, 0xBB, 0xBB, 0xBB, 0xBC, 0xBC, 0xBB, 0xBD, 0xCD, 0xDD, 0xDD, 0xED, 0xDD, 0xDD, 0xDD, 	/* Line: 33 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xEE, 0xDC, 0xDC, 0xBB, 0xBB, 0xB9, 0xB9, 0x99, 0x99, 0x98, 0x99, 0x98, 0x99, 0x89, 0x99, 0x99, 0x99, 0x9B, 0xB9, 0xBB, 0xBB, 0x99, 0xCB, 0xCC, 0xCC, 0xCD, 0xCC, 0xCC, 0xCC, 0xCC, 	/* Line: 34 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEE, 0xED, 0xDB, 0xBB, 0xBB, 0x99, 0x99, 0x99, 0x99, 0x98, 0x88, 0x87, 0x77, 0x77, 0x78, 0x88, 0x88, 0x99, 0x99, 0x79, 0x88, 0x98, 0x89, 0xB9, 0xBB, 0xBB, 0xCB, 0xCB, 0xBC, 0xBC, 0xBC, 	/* Line: 35 */
  0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEE, 0xDC, 0xCB, 0xBB, 0x99, 0x99, 0x99, 0x99, 0x88, 0x77, 0x77, 0x75, 0x57, 0x77, 0x77, 0x77, 0x75, 0x75, 0x53, 0x35, 0x57, 0x35, 0x87, 0x78, 0x98, 0x9B, 0x9B, 0xBB, 0xBB, 0xBB, 0xBB, 	/* Line: 36 */
  0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xED, 0xCC, 0xBB, 0x99, 0x99, 0x99, 0x98, 0x88, 0x87, 0x77, 0x55, 0x55, 0x55, 0x55, 0x33, 0x33, 0x31, 0x11, 0x11, 0x11, 0x11, 0x11, 0x33, 0x33, 0x55, 0x77, 0x89, 0x99, 0xBB, 0xBB, 0xBB, 	/* Line: 37 */
  0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEE, 0xDC, 0xCB, 0xBB, 0xB9, 0x99, 0x99, 0x89, 0x88, 0x77, 0x75, 0x55, 0x55, 0x53, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x11, 0x13, 0x13, 0x57, 0x89, 0x99, 0x99, 0x99, 	/* Line: 38 */
  0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xED, 0xCC, 0xBB, 0xB9, 0x99, 0x89, 0x98, 0x88, 0x87, 0x77, 0x77, 0x53, 0x31, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x11, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x30, 0x03, 0x55, 0x88, 0x79, 0x9B, 	/* Line: 39 */
  0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xDD, 0xCB, 0xBB, 0x99, 0x99, 0x99, 0x88, 0x88, 0x77, 0x77, 0x75, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x33, 0x33, 0x00, 0x00, 0x00, 0x01, 0x00, 0x37, 0x30, 0x33, 0x55, 0x79, 0x99, 	/* Line: 40 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEE, 0xDC, 0xBB, 0xB9, 0x99, 0x98, 0x98, 0x99, 0x88, 0x77, 0x77, 0x30, 0x00, 0x00, 0x00, 0x00, 0x10, 0x01, 0x31, 0x33, 0xBC, 0x97, 0x31, 0x00, 0x00, 0x00, 0x00, 0x07, 0x93, 0x13, 0x33, 0x75, 0x77, 	/* Line: 41 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0x0F, 0xF0, 0x00, 0x0F, 0xFF, 0xFF, 0xF0, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEE, 0xCC, 0xBB, 0x9B, 0x99, 0x99, 0x89, 0x99, 0x87, 0x78, 0x73, 0x00, 0x00, 0x00, 0x00, 0x01, 0x33, 0x13, 0x13, 0x15, 0x9C, 0xCC, 0x97, 0x30, 0x00, 0x00, 0x00, 0x00, 0x78, 0x30, 0x33, 0x35, 0x78, 	/* Line: 42 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x0F, 0xFF, 0xF0, 0x00, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xED, 0xCB, 0xB9, 0x99, 0x98, 0x88, 0x89, 0x88, 0x87, 0x87, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x13, 0x35, 0x33, 0x31, 0x5C, 0xCD, 0xDC, 0x95, 0x30, 0x00, 0x00, 0x00, 0x01, 0x33, 0x33, 0x35, 0x77, 	/* Line: 43 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0x0F, 0xF0, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xED, 0xCB, 0xBB, 0x99, 0x89, 0x89, 0x98, 0x88, 0x78, 0x71, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x33, 0x33, 0x35, 0x8D, 0xCD, 0xDD, 0xCB, 0x73, 0x00, 0x00, 0x00, 0x00, 0x33, 0x33, 0x55, 0x55, 	/* Line: 44 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xDC, 0xCB, 0xB9, 0x98, 0x88, 0x99, 0x98, 0x77, 0x87, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x13, 0x13, 0x33, 0x9E, 0xDD, 0xED, 0xDB, 0x98, 0x11, 0x00, 0x00, 0x00, 0x05, 0x75, 0x53, 0x37, 	/* Line: 45 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEC, 0xCB, 0xB9, 0x98, 0x98, 0x98, 0x97, 0x78, 0x73, 0x13, 0x10, 0x01, 0x11, 0x00, 0x00, 0x00, 0x00, 0x13, 0x31, 0x35, 0xCE, 0xED, 0xDE, 0xDC, 0xB9, 0x33, 0x30, 0x01, 0x10, 0x01, 0x33, 0x55, 0x55, 	/* Line: 46 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xDD, 0xCB, 0xB9, 0x89, 0x98, 0x98, 0x87, 0x77, 0x31, 0x53, 0x30, 0x01, 0x11, 0x11, 0x00, 0x00, 0x01, 0x31, 0x13, 0x39, 0xEE, 0xDE, 0xDC, 0xDC, 0xB8, 0x33, 0x33, 0x10, 0x11, 0x00, 0x03, 0x35, 0x57, 	/* Line: 47 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xED, 0xCB, 0xB9, 0x99, 0x89, 0x88, 0x77, 0x73, 0x35, 0x33, 0x31, 0x00, 0x11, 0x11, 0x00, 0x01, 0x33, 0x33, 0x33, 0x5B, 0xEE, 0xFE, 0xED, 0xCD, 0xC8, 0x33, 0x35, 0x31, 0x33, 0x13, 0x10, 0x03, 0x35, 	/* Line: 48 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEE, 0xCB, 0xB9, 0x98, 0x98, 0x87, 0x78, 0x73, 0x33, 0x55, 0x53, 0x00, 0x01, 0x11, 0x11, 0x31, 0x31, 0x31, 0x33, 0x9E, 0xEE, 0xEF, 0xFE, 0xDE, 0x95, 0x55, 0x85, 0x78, 0x55, 0x77, 0x55, 0x33, 0x35, 	/* Line: 49 */
  0xFF, 0xF0, 0xFF, 0xFF, 0xFF, 0x0F, 0xFF, 0xFF, 0x0F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x0F, 0xFF, 0xF0, 0x0F, 0xFF, 0xFF, 0xF0, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEE, 0x0B, 0xB9, 0x99, 0x89, 0x88, 0x88, 0x83, 0x53, 0x53, 0x55, 0x30, 0x00, 0x10, 0x31, 0x13, 0x13, 0x31, 0x38, 0xCE, 0xEF, 0xFE, 0xEE, 0xD9, 0x55, 0x35, 0x77, 0x57, 0x8B, 0x88, 0x97, 0x75, 0x33, 	/* Line: 50 */
  0xFF, 0x00, 0xFF, 0xFF, 0xFF, 0x0F, 0xFF, 0xFF, 0xFF, 0xF0, 0xFF, 0xFF, 0xFF, 0xF0, 0xF0, 0x0F, 0xFF, 0x0F, 0xFF, 0xFF, 0xFF, 0xF0, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0x0C, 0xB9, 0x98, 0x88, 0x88, 0x98, 0x75, 0x33, 0x53, 0x55, 0x53, 0x10, 0x00, 0x03, 0x11, 0x31, 0x33, 0x8C, 0xEF, 0xEE, 0xFF, 0xEC, 0x83, 0x33, 0x37, 0x98, 0x7B, 0xDD, 0xB9, 0x89, 0x9B, 0x99, 	/* Line: 51 */
  0xF0, 0xF0, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0x0F, 0x00, 0x00, 0xFF, 0xFF, 0x0F, 0xFF, 0x0F, 0xF0, 0xFF, 0xFF, 0xFF, 0xFF, 0xF0, 0xFF, 0xF0, 0x00, 0xFF, 0x0F, 0xFF, 0x0F, 0xF0, 0x00, 0xFE, 0x0C, 0xBB, 0x99, 0x98, 0x89, 0x95, 0x33, 0x33, 0x13, 0x33, 0x35, 0x53, 0x10, 0x00, 0x03, 0x13, 0x59, 0xCE, 0xDD, 0xEE, 0xEC, 0x95, 0x33, 0x33, 0xBC, 0xB9, 0xB9, 0xCD, 0xDD, 0xBB, 0xBB, 0xBB, 	/* Line: 52 */
  0x0F, 0xF0, 0xFF, 0x00, 0x0F, 0x0F, 0xFF, 0x0F, 0x0F, 0xF0, 0xFF, 0xFF, 0xF0, 0xFF, 0xFF, 0x0F, 0xF0, 0x00, 0x0F, 0xF0, 0x00, 0xF0, 0xFF, 0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0x0E, 0x0C, 0xCB, 0x99, 0x88, 0x88, 0x73, 0x13, 0x30, 0x11, 0x13, 0x33, 0x33, 0x33, 0x33, 0x33, 0x59, 0xBC, 0xBC, 0xDD, 0xCB, 0x95, 0x30, 0x33, 0x88, 0xBD, 0xED, 0xBD, 0xBE, 0xDD, 0xCC, 0xBB, 0xDC, 	/* Line: 53 */
  0x00, 0x00, 0x0F, 0xFF, 0xFF, 0x0F, 0xFF, 0x0F, 0x0F, 0xF0, 0xFF, 0xFF, 0x0F, 0xFF, 0xFF, 0x0F, 0xF0, 0xFF, 0xF0, 0xFF, 0xFF, 0xF0, 0xFF, 0x00, 0x00, 0xFF, 0x0F, 0xFF, 0x0F, 0x00, 0x00, 0xFE, 0x0D, 0xCB, 0xB9, 0x99, 0x89, 0x51, 0x33, 0x33, 0x13, 0x13, 0x13, 0x33, 0x53, 0x35, 0x57, 0x78, 0x99, 0x99, 0x98, 0x53, 0x10, 0x13, 0x79, 0x98, 0xBC, 0xCB, 0xBE, 0xDD, 0xED, 0xDD, 0xCC, 0xCC, 	/* Line: 54 */
  0xFF, 0xF0, 0xFF, 0xFF, 0xFF, 0x0F, 0xFF, 0x0F, 0x0F, 0xF0, 0xF0, 0xF0, 0xFF, 0xFF, 0xFF, 0x0F, 0xF0, 0xFF, 0xF0, 0xFF, 0xFF, 0xF0, 0xFF, 0x0F, 0xFF, 0xFF, 0xF0, 0xF0, 0xFF, 0x0F, 0xFF, 0xFF, 0x0D, 0xCB, 0xB9, 0x98, 0x88, 0x53, 0x53, 0x33, 0x33, 0x33, 0x53, 0x33, 0x33, 0x33, 0x33, 0x31, 0x33, 0x13, 0x11, 0x11, 0x13, 0x37, 0x88, 0x89, 0xBC, 0xCC, 0xCC, 0xCC, 0xCD, 0xDD, 0xCD, 0xDC, 	/* Line: 55 */
  0xFF, 0xF0, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0x00, 0xFF, 0x0F, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0xFF, 0x00, 0x0F, 0xFF, 0xFF, 0xF0, 0x0F, 0xF0, 0x00, 0xFF, 0xFF, 0x0F, 0xFF, 0xF0, 0x00, 0xFF, 0x00, 0xCC, 0xB9, 0x98, 0x88, 0x75, 0x57, 0x75, 0x57, 0x55, 0x55, 0x55, 0x75, 0x33, 0x35, 0x33, 0x31, 0x33, 0x13, 0x35, 0x55, 0x77, 0x98, 0x79, 0xB9, 0xBC, 0xFD, 0xDD, 0xCB, 0xBD, 0xDC, 0xDC, 	/* Line: 56 */
  0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEE, 0xDC, 0xBB, 0x99, 0x88, 0x87, 0x77, 0x77, 0x57, 0x77, 0x88, 0x77, 0x55, 0x55, 0x57, 0x55, 0x57, 0x77, 0x55, 0x79, 0x88, 0xB9, 0x99, 0x87, 0x9C, 0xB9, 0xBC, 0xFE, 0xDD, 0xED, 0xDE, 0xDE, 	/* Line: 57 */
  0xF0, 0x00, 0xFF, 0x0F, 0xFF, 0xFF, 0x00, 0x00, 0x0F, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0xFF, 0x00, 0x00, 0xFF, 0xF0, 0x00, 0xFF, 0x00, 0x00, 0xFF, 0x0F, 0xFF, 0x0F, 0x00, 0x0F, 0xF0, 0x00, 0xDC, 0xBB, 0x99, 0x88, 0x89, 0x88, 0x79, 0x77, 0x75, 0x78, 0x89, 0x98, 0x87, 0x77, 0x77, 0x89, 0x99, 0x98, 0x77, 0x99, 0x9B, 0xBC, 0xCB, 0x9B, 0xDE, 0xBB, 0xDD, 0xED, 0xEE, 0xEE, 0xEE, 	/* Line: 58 */
  0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0xFF, 0x0F, 0xFF, 0xFF, 0x0F, 0xFF, 0x0F, 0xFF, 0xFF, 0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0x0F, 0xF0, 0xFF, 0x0F, 0xFE, 0x0D, 0xCB, 0x99, 0x88, 0x88, 0x98, 0x78, 0x87, 0x77, 0x77, 0x88, 0x9B, 0x89, 0x98, 0x99, 0x98, 0x89, 0xB9, 0x99, 0xB9, 0xB9, 0xBD, 0xDE, 0xDB, 0xBC, 0xEC, 0xCE, 0xEE, 0xEE, 0xEE, 0xFE, 	/* Line: 59 */
  0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0xFF, 0x0F, 0xFF, 0xFF, 0x0F, 0xFF, 0x0F, 0xFF, 0xFF, 0x0F, 0xFF, 0xFF, 0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0x0F, 0xF0, 0xFF, 0x0F, 0xFE, 0xED, 0xCB, 0xB9, 0x99, 0x88, 0x88, 0x87, 0x85, 0x77, 0x77, 0x88, 0x89, 0x98, 0xBB, 0x99, 0xB9, 0x89, 0xB9, 0xBB, 0xBC, 0xDC, 0xCC, 0xED, 0xEF, 0xDD, 0xDE, 0xDE, 0xED, 0xEE, 0xEE, 0xFE, 	/* Line: 60 */
  0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0x0F, 0xFF, 0x0F, 0xFF, 0xFF, 0x0F, 0x00, 0x0F, 0x00, 0x00, 0xFF, 0x0F, 0xFF, 0x0F, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x0F, 0xF0, 0xFF, 0x0F, 0xFF, 0xEE, 0xCB, 0xB9, 0x98, 0x88, 0x88, 0x99, 0x77, 0x75, 0x77, 0x78, 0x88, 0x99, 0x89, 0x9B, 0xBB, 0xBB, 0xBB, 0xBB, 0xCC, 0xCD, 0xCC, 0xDD, 0xEE, 0xED, 0xDE, 0xED, 0xEF, 0xEE, 0xEE, 0xFF, 	/* Line: 61 */
  0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0xFF, 0x0F, 0xFF, 0xFF, 0x0F, 0xFF, 0x0F, 0xFF, 0xFF, 0x0F, 0xFF, 0x0F, 0x0F, 0xF0, 0xFF, 0x00, 0x00, 0x0F, 0x0F, 0xFF, 0xFF, 0x0F, 0xFF, 0x0F, 0xF0, 0xFF, 0x0F, 0xFF, 0xED, 0xDC, 0xB9, 0x99, 0x88, 0x88, 0x88, 0x87, 0x77, 0x77, 0x77, 0x78, 0x89, 0x98, 0x9B, 0x99, 0xBB, 0x9B, 0xBB, 0xCC, 0xBD, 0xCC, 0xCD, 0xEE, 0xED, 0xEE, 0xEF, 0xEE, 0xFE, 0xEF, 0xFF, 	/* Line: 62 */
  0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0xFF, 0x0F, 0xFF, 0xFF, 0x0F, 0xFF, 0x0F, 0xFF, 0xFF, 0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0xFF, 0x0F, 0xFF, 0x0F, 0xF0, 0xFF, 0x0F, 0xFF, 0x0E, 0xDC, 0xBB, 0x99, 0x98, 0x88, 0x88, 0x87, 0x77, 0x77, 0x77, 0x78, 0x88, 0x89, 0x99, 0x9B, 0x99, 0x9B, 0xBB, 0xBB, 0xBC, 0xCD, 0xDD, 0xDD, 0xED, 0xEE, 0xEE, 0xEF, 0xEF, 0xEE, 0xEF, 	/* Line: 63 */
  0xF0, 0x00, 0xFF, 0x00, 0x00, 0x0F, 0x00, 0x00, 0x0F, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xF0, 0x00, 0x0F, 0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0x0F, 0x0F, 0xFF, 0xFF, 0x0F, 0xFF, 0x0F, 0x00, 0x0F, 0xF0, 0x00, 0xEE, 0xDC, 0xBB, 0xB9, 0x99, 0x89, 0x98, 0x88, 0x88, 0x77, 0x88, 0x88, 0x99, 0x99, 0x9B, 0xB9, 0x9B, 0xBB, 0xBB, 0xCB, 0xCC, 0xCC, 0xCD, 0xDE, 0xEE, 0xEF, 0xFF, 0xFF, 0xFE, 0xEF, 0xFF	/* Line: 64 */
};

void delay(uint32_t twait)
{
	while (twait--)
		asm volatile ("nop");
}

void WriteCommand(unsigned command)
{

	PORTA = command;	// set up data on bus
  CLR_CS;   // chip selected
  CLR_CD;   // command mode

#ifdef MODE6800

  CLR_RW;

	// clock E
  SET_E;
  CLR_E;

#else 

  SET_RD;

	// clock WR
  CLR_WR;
  SET_WR;

#endif

  SET_CS;   // deselect chip
}

void WriteData(unsigned data)
{
	PORTA = data;	// set up data on bus
  SET_CD;       // data mode
  CLR_CS;       // chip selected

#ifdef MODE6800

  CLR_RW; 

	// clock E
  SET_E;
  CLR_E;

#else           // 8080 mode

  SET_RD;

	// clock WR
  CLR_WR;
  SET_WR;

#endif

  SET_CS;       // deselect chip
}

void reset_display(void)
{
	CLR_RESET;
  delay(10000);
  SET_RESET;
}

void init_OLED()
{
	reset_display();

  // Column Address
	WriteCommand(0x15); 	// Set Column Address 
	  WriteCommand(0x00); 	  // Start = 0 
	  WriteCommand(0x3F); 	  // End = 127 

  // Row Address
	WriteCommand(0x75); 	// Set Row Address 
	  WriteCommand(0x0C); 	  // Start = 0 
	  WriteCommand(0x4B); 	  // End = 63 

  // Contrast Control
	WriteCommand(0x81); 	// Set Contrast Control 
	  WriteCommand(0x38); 	  // 0 ~ 127 

  // Current Range
	WriteCommand(0x86); 	// Set Current Range84h:Quarter, 85h:Half,86h:Full

  // Re-map
	WriteCommand(0xA0); 	// Set Re-map 
	  WriteCommand(0x52); 	  // [0]:MX, [1]:Nibble, [2]:H/Vaddress [4]:MY, [6]:Com Split Odd/Even "1000010"

  // Display Start Line
	WriteCommand(0xA1); 	// Set Display Start Line 
	  WriteCommand(0x0c); 	  // Top 

  // Display Offset
	WriteCommand(0xA2); 	// Set Display Offset 
	  WriteCommand(0x4C); 	  // No offset 

  // Display Mode
	WriteCommand(0xA4); 	// Set Display Mode,A4:Normal,A5:All ON, A6: All OFF,A7:Inverse 

  // Multiplex Ratio
	WriteCommand(0xA8); 	// Set Multiplex Ratio 
	  WriteCommand(0x3F); 	  // [6:0]16~128, 64 rows=3Fh

  // Phase Length
	WriteCommand(0xB1); 	// Set Phase Length 
	  WriteCommand(0x22); 	  // [3:0]:Phase 1 period of 1~16clocks 
							  // [7:4]:Phase 2 period of 1~16clocks // POR = 0111 0100 
  // Row Period
	WriteCommand(0xB2); 	// Set Row Period 
	  WriteCommand(0x46); 	  // [7:0]:18~255,K=P1+P2+GS15 (POR:4+7+29)

  // Display Clock Divide
	WriteCommand(0xB3); 	// Set Clock Divide 
	  WriteCommand(0x41); 	  // [3:0]:1~16, [7:4]:0~16 
                              // POR = 0000 0001 
  // VSL
	WriteCommand(0xBF); 	// Set VSL 
	  WriteCommand(0x0D); 	  // [3:0]:VSL 

  // CCOMH
	WriteCommand(0xBE); 	// Set VCOMH 
	  WriteCommand(0x00); 	  // [7:0]:VCOMH 

  // VP
	WriteCommand(0xBC); 	// Set VP 
	  WriteCommand(0x0B); 	  // [7:0]:VP 

  // Gamma
	WriteCommand(0xB8); 	// Set Gamma with next 8 bytes
	WriteCommand(0x01); 	  // L1[2:1] 
	WriteCommand(0x11); 	  // L3[6:4], L2[2:0] 0001 0001
	WriteCommand(0x22); 	  // L5[6:4], L4[2:0] 0010 0010
	WriteCommand(0x32); 	  // L7[6:4], L6[2:0] 0011 1011
	WriteCommand(0x43); 	  // L9[6:4], L8[2:0] 0100 0100
	WriteCommand(0x54); 	  // LB[6:4], LA[2:0] 0101 0101
	WriteCommand(0x65); 	  // LD[6:4], LC[2:0] 0110 0110
	WriteCommand(0x76); 	  // LF[6:4], LE[2:0] 1000 0111

  // Set DC-DC
	WriteCommand(0xAD); 	// Set DC-DC 
	  WriteCommand(0x02); 	  // 03=ON, 02=Off 

  // Display ON/OFF
	WriteCommand(0xAF); 	// AF=ON, AE=Sleep Mode 


}

void show_bitmap()
{
	unsigned char j=0;
  unsigned char i=0;

  WriteCommand(0xA4);   // normal display

  for(i=0;i<64;i++)
  {
    for(j=0;j<64;j++)
    {
      WriteData(Data_12864greynocolorsbmp[(i<<6)+j]);
    }
  }
}

int main()
{

	PORTD = 0;	  	// all off
	DDRD |= (1<<3);	// VPP output

	DDRA = 0xFF;    // set PORTA for output

  #ifdef MODE6800
  	PORTC = 0b11011110;
  #else
  	PORTC = 0b11111110;
  #endif

	DDRC = 0xFE;

	DDRD |= 0x06;	// OLED pins output

	// enable VPP
	PORTD |= (1<<3);

	delay(20000L);

  init_OLED();          // initialize OLED module

  show_bitmap();        // display image

  while(1);

  return 0;
}

